==> ttcomment-0.0.3.tar.gz: lib/comment_http/default_http_transformer.dart <==
/*
 * @Descripttion: 
 * @version: 
 * @Author: TT
 * @Date: 2021-07-16 09:40:43
 * @LastEditors: ftt
 * @LastEditTime: 2022-05-13 10:51:04
 */

import 'package:dio/dio.dart';

import '../ttcomment.dart';

//  服务器默认返回的数据接口合适
//   {
//     "code": 200,
//     "data": {} || [] || null,
//     "msg": "success"
// }

///Http配置.
class NormalHttpConfig {
  /// constructor.
  NormalHttpConfig(
      {this.status, this.code, this.msg, this.data, this.successcode});

  /// BaseResp [String status]字段 key, 默认：status.
  String? status;

  /// BaseResp [int code]字段 key, 默认：errorCode.
  String? code;

  /// BaseResp [String msg]字段 key, 默认：errorMsg.
  String? msg;

  /// BaseResp [T data]字段 key, 默认：data.
  String? data;

  /// 判断请求成功的值
  int? successcode;
}

class DefaultHttpTransformer extends HttpTransformer {
  String _statuskey = 'status';
  String _codekey = "code";
  String _msgkey = 'msg';
  String _datakey = "data";
  int _successcode = 1;

  @override
  HttpResponse parse(Response response) {
    var json = response.data as Map<String, dynamic>?;
    if (json == null) {
      return HttpResponse.failure(errorMsg: '请求的数据为空', errorCode: -1);
    }
    var status = json[_statuskey];
    int code = 0;
    if (status is bool) {
      if (status) {
        code = 1;
      }
    } else {
      if (status == _successcode) {
        code = 1;
      }
    }
    if (code == 1) {
      return HttpResponse.success(json[_datakey] ?? json,
          response: json, msg: json[_msgkey]);
    }
    return HttpResponse.failure(
        errorMsg: (json[_msgkey] != null) ? json[_msgkey] : "",
        errorCode: code,
        data: json[_datakey] ?? json);
  }

  ///
  setHttpConfig({required NormalHttpConfig config}) {
    _statuskey = config.status ?? _statuskey;
    _datakey = config.data ?? _datakey;
    _msgkey = config.msg ?? _msgkey;
    _codekey = config.code ?? _codekey;
    _successcode = config.successcode ?? _successcode;
  }

  /// 单例对象
  static final DefaultHttpTransformer _instance =
      DefaultHttpTransformer._internal();

  /// 内部构造方法，可避免外部暴露构造函数，进行实例化
  DefaultHttpTransformer._internal();

  /// 工厂构造方法，这里使用命名构造函数方式进行声明
  factory DefaultHttpTransformer.getInstance() => _instance;
}

==> ttcomment-0.0.4.tar.gz: lib/comment_http/default_http_transformer.dart <==
/*
 * @Descripttion: 
 * @version: 
 * @Author: TT
 * @Date: 2021-07-16 09:40:43
 * @LastEditors: TT
 * @LastEditTime: 2022-08-30 14:45:40
 */

import 'package:dio/dio.dart';

import '../ttcomment.dart';

//  服务器默认返回的数据接口合适
//   {
//     "code": 200,
//     "data": {} || [] || null,
//     "msg": "success"
// }

///Http配置.
class NormalHttpConfig {
  /// constructor.
  NormalHttpConfig(
      {this.status, this.code, this.msg, this.data, this.successcode});

  /// BaseResp [String status]字段 key, 默认：status.
  String? status;

  /// BaseResp [int code]字段 key, 默认：errorCode.
  String? code;

  /// BaseResp [String msg]字段 key, 默认：errorMsg.
  String? msg;

  /// BaseResp [T data]字段 key, 默认：data.
  String? data;

  /// 判断请求成功的值
  int? successcode;
}

class DefaultHttpTransformer extends HttpTransformer {
  String _statuskey = 'status';
  String _codekey = "code";
  String _msgkey = 'msg';
  String _datakey = "data";
  int _successcode = 1;

  @override
  HttpResponse parse(Response response) {
    var json = response.data as Map<String, dynamic>?;
    if (json == null) {
      return HttpResponse.failure(errorMsg: '请求的数据为空', errorCode: -1);
    }
    var status = json[_statuskey];
    int code = 0;
    if (status is bool) {
      if (status) {
        code = 1;
      }
    } else {
      if (status == _successcode) {
        code = 1;
      }
    }
    if (code == 1) {
      return HttpResponse.success(json[_datakey] ?? json,
          response: json, reqmsg: json[_msgkey]);
    }
    return HttpResponse.failure(
        errorMsg: (json[_msgkey] != null) ? json[_msgkey] : "",
        errorCode: code,
        data: json[_datakey] ?? json);
  }

  ///
  setHttpConfig({required NormalHttpConfig config}) {
    _statuskey = config.status ?? _statuskey;
    _datakey = config.data ?? _datakey;
    _msgkey = config.msg ?? _msgkey;
    _codekey = config.code ?? _codekey;
    _successcode = config.successcode ?? _successcode;
  }

  /// 单例对象
  static final DefaultHttpTransformer _instance =
      DefaultHttpTransformer._internal();

  /// 内部构造方法，可避免外部暴露构造函数，进行实例化
  DefaultHttpTransformer._internal();

  /// 工厂构造方法，这里使用命名构造函数方式进行声明
  factory DefaultHttpTransformer.getInstance() => _instance;
}
